#region License
// Copyright (c) 2005 Alexander Kolliopoulos
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would
//    be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such, and must not
//    be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
#endregion

using System;
using System.Runtime.Serialization;

namespace Lydos.Tablets
{
    #region TabletException
    /// <summary>
    /// The base class for exceptions caused by tablet errors.
    /// </summary>
    [Serializable]
    public class TabletException : Exception
    {
        /// <summary>
        /// Initializes a new instance of this class.
        /// </summary>
        public TabletException() : base() { }

        /// <summary>
        /// Initializes a new instance of this class with a specified error message.
        /// </summary>
        /// <param name="message">A string that describes the error.</param>
        public TabletException(string message) : base(message) { }

        /// <summary>
        /// Initializes a new instance of this class with a specified error message and a reference to the inner exception that is the cause of this exception.
        /// </summary>
        /// <param name="message">A string that describes the error.</param>
        /// <param name="inner">The exception that is the cause of the current exception.</param>
        public TabletException(string message, Exception inner) : base(message, inner) { }

        /// <summary>
        /// Initializes a new instance of this class with serialized data.
        /// </summary>
        /// <param name="info">The object that holds the serialized object data.</param>
        /// <param name="context">The contextual information about the source or destination.</param>
        protected TabletException(SerializationInfo info, StreamingContext context) : base(info, context) { }
    }
    #endregion

    #region TabletNotPresentException
    /// <summary>
    /// The exception that is thrown when no tablet is physically connected.
    /// </summary>
    [Serializable]
    public class TabletNotPresentException : TabletException
    {
        /// <summary>
        /// Initializes a new instance of this class.
        /// </summary>
        public TabletNotPresentException() : base() { }

        /// <summary>
        /// Initializes a new instance of this class with a specified error message.
        /// </summary>
        /// <param name="message">A string that describes the error.</param>
        public TabletNotPresentException(string message) : base(message) { }

        /// <summary>
        /// Initializes a new instance of this class with a specified error message and a reference to the inner exception that is the cause of this exception.
        /// </summary>
        /// <param name="message">A string that describes the error.</param>
        /// <param name="inner">The exception that is the cause of the current exception.</param>
        public TabletNotPresentException(string message, Exception inner) : base(message, inner) { }

        /// <summary>
        /// Initializes a new instance of this class with serialized data.
        /// </summary>
        /// <param name="info">The object that holds the serialized object data.</param>
        /// <param name="context">The contextual information about the source or destination.</param>
        protected TabletNotPresentException(SerializationInfo info, StreamingContext context) : base(info, context) {}
    }
    #endregion

    #region TabletOperationFailedException
    /// <summary>
    /// The exception that is thrown when a wintab function call failed.
    /// </summary>
    [Serializable]
    public class TabletOperationFailedException : TabletException
    {
        /// <summary>
        /// Initializes a new instance of this class.
        /// </summary>
        public TabletOperationFailedException() : base() { }

        /// <summary>
        /// Initializes a new instance of this class with a specified error message.
        /// </summary>
        /// <param name="message">A string that describes the error.</param>
        public TabletOperationFailedException(string message) : base(message) { }

        /// <summary>
        /// Initializes a new instance of this class with a specified error message and a reference to the inner exception that is the cause of this exception.
        /// </summary>
        /// <param name="message">A string that describes the error.</param>
        /// <param name="inner">The exception that is the cause of the current exception.</param>
        public TabletOperationFailedException(string message, Exception inner) : base(message, inner) { }

        /// <summary>
        /// Initializes a new instance of this class with serialized data.
        /// </summary>
        /// <param name="info">The object that holds the serialized object data.</param>
        /// <param name="context">The contextual information about the source or destination.</param>
        protected TabletOperationFailedException(SerializationInfo info, StreamingContext context) : base(info, context) {}
    }
    #endregion

    #region TabletPacketNotFoundException
    /// <summary>
    /// The exception that is thrown when a tablet packet was not found.
    /// </summary>
    [Serializable]
    public class TabletPacketNotFoundException : TabletException
    {
        /// <summary>
        /// Initializes a new instance of this class.
        /// </summary>
        public TabletPacketNotFoundException() : base() { }

        /// <summary>
        /// Initializes a new instance of this class with a specified error message.
        /// </summary>
        /// <param name="message">A string that describes the error.</param>
        public TabletPacketNotFoundException(string message) : base(message) { }

        /// <summary>
        /// Initializes a new instance of this class with a specified error message and a reference to the inner exception that is the cause of this exception.
        /// </summary>
        /// <param name="message">A string that describes the error.</param>
        /// <param name="inner">The exception that is the cause of the current exception.</param>
        public TabletPacketNotFoundException(string message, Exception inner) : base(message, inner) { }

        /// <summary>
        /// Initializes a new instance of this class with serialized data.
        /// </summary>
        /// <param name="info">The object that holds the serialized object data.</param>
        /// <param name="context">The contextual information about the source or destination.</param>
        protected TabletPacketNotFoundException(SerializationInfo info, StreamingContext context) : base(info, context) {}
    }
    #endregion
}
