#region License
// Copyright (c) 2005 Alexander Kolliopoulos
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would
//    be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such, and must not
//    be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
#endregion

using System;

namespace Lydos.Tablets
{
    /// <summary>
    /// Provides data for a tablet event.
    /// </summary>
    public class TabletEventArgs : EventArgs
    {
        #region Fields
        int x;
        int y;
        int normalPressure;
        int buttons;
        #endregion

        #region Constructors
        /// <summary>
        /// Initializes a new instance with all fields set.
        /// </summary>
        /// <param name="x">The x-position of the pen in client coordinates.</param>
        /// <param name="y">The y-position of the pen in client coordinates.</param>
        /// <param name="normalPressure">The normal pressure of the pen on the tablet.</param>
        /// <param name="buttons">Which buttons are pressed.</param>
        public TabletEventArgs(int x, int y, int normalPressure, int buttons)
        {
            this.x = x;
            this.y = y;
            this.normalPressure = normalPressure;
            this.buttons = buttons;
        }
        #endregion

        #region Properties
        /// <summary>
        /// The x-position of the pen.
        /// </summary>
        /// <value>The x-position of the pen in client coordinates.</value>
        public int X
        {
            get
            {
                return x;
            }
        }

        /// <summary>
        /// The y-position of the pen.
        /// </summary>
        /// <value>The y-position of the pen in client coordinates.</value>
        public int Y
        {
            get
            {
                return y;
            }
        }

        /// <summary>
        /// The normal pressure of the pen on the tablet.
        /// </summary>
        /// <value>The normal pressure of the pen, with maximum value dependent upon hardware.</value>
        public int NormalPressure
        {
            get
            {
                return normalPressure;
            }
        }

        /// <summary>
        /// Which buttons are pressed.
        /// </summary>
        /// <value>The raw code for the pressed pen buttons.</value>
        public int Buttons
        {
            get
            {
                return buttons;
            }
        }
        #endregion
    }
}
