#region License
// Copyright (c) 2005 Alexander Kolliopoulos
//
// This software is provided 'as-is', without any express or implied
// warranty. In no event will the authors be held liable for any damages
// arising from the use of this software.
//
// Permission is granted to anyone to use this software for any purpose,
// including commercial applications, and to alter it and redistribute it
// freely, subject to the following restrictions:
//
// 1. The origin of this software must not be misrepresented; you must not
//    claim that you wrote the original software. If you use this software
//    in a product, an acknowledgment in the product documentation would
//    be appreciated but is not required.
//
// 2. Altered source versions must be plainly marked as such, and must not
//    be misrepresented as being the original software.
//
// 3. This notice may not be removed or altered from any source distribution.
#endregion

using System;
using System.Security.Permissions;
using System.Windows.Forms;

namespace Lydos.Tablets
{
    /// <summary>
    /// Provides a simple class to inherit from to get tablet functionality.
    /// </summary>
    public class TabletForm : Form
    {
        #region Fields
        Tablet tablet;
        #endregion

        #region Constructors
        /// <summary>
        /// Creates a form with a new <see cref="Tablet"/> object.
        /// </summary>
        public TabletForm()
        {
            tablet = new Tablet(this);
        }

        /// <summary>
        /// Creates a form with a new <see cref="Tablet"/> object with the specified message handling behavior.
        /// </summary>
        /// <param name="consumeTabletEvents">True to prevent the system from receiving tablet events, or false for normal cursor behavior.</param>
        public TabletForm(bool consumeTabletEvents)
        {
            tablet = new Tablet(this, consumeTabletEvents);
        }
        #endregion

        #region Destructor
        /// <summary>
        /// Final disposal of object.
        /// </summary>
        /// <param name="disposing">True if called explicitly, false if finalizing.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                if (tablet != null)
                {
                    tablet.Close();
                }
            }
            base.Dispose(disposing);
        }
        #endregion

        #region Properties
        /// <summary>
        /// The <see cref="Tablet"/> for this control.
        /// </summary>
        /// <value>A <see cref="Tablet"/> object that consumes tablet events for this control.</value>
        protected Tablet Tablet
        {
            get
            {
                return tablet;
            }
        }
        #endregion

        #region WndProc
        /// <summary>
        /// This is overriden to provide the tablet object with messages.
        /// </summary>
        /// <param name="m">The Windows message.</param>
        [SecurityPermission(SecurityAction.LinkDemand, Flags = SecurityPermissionFlag.UnmanagedCode)]
        protected override void WndProc(ref Message m)
        {
            if (tablet != null)
            {
                tablet.ProcessMessage(m);
            }
            base.WndProc(ref m);
        }
        #endregion
    }
}
